pub struct GetAssertionPrfInput {
pub eval: Option<PrfInputValues>,
pub eval_by_credential: Option<HashMap<Vec<u8>, PrfInputValues>>,
}Expand description
Input for WebAuthn PRF extension during authentication ceremonies.
Fields
eval: Option<PrfInputValues>A PRF input to use for authentication. If a map of credential IDs to PRF
inputs is specified in Self::eval_by_credential along with this
value, the extension will fallback to this
value if the returned credential ID is not contained in the map.
eval_by_credential: Option<HashMap<Vec<u8>, PrfInputValues>>A map of credential IDs to PRF input for a set of credentials specified in the
GetAssertionRequest::allow_list field of the request. If a key of
this map does not exist in the allow list, the extension will fail.